使用 python3  + click  编写的个人常用的工具  

* 简易批量管理服务器
* 在线备份配置 tools 配置  
* 建议http共享目录
* 获取设备基本信息 
* 快速初始化本地常用sdk  


```shell script
# ubuntu 使用python3 版本的pip 名字默认为pip3 
#安装
pip3 install jiuming-tools
#更新
pip3 install --upgrade jiuming-tools
# 使用
ming 
```